@@ -31,6 +31,7 @@ type Route53 struct {
 	zoneNames []string
 	client    route53iface.Route53API
 	upstream  *upstream.Upstream
+	refresh   time.Duration
 
 	zMu   sync.RWMutex
 	zones zones
@@ -45,11 +46,11 @@ type zone struct {
 type zones map[string][]*zone
 
 // New reads from the keys map which uses domain names as its key and hosted
-// zone id lists as its values, validates that each domain name/zone id pair does
-// exist, and returns a new *Route53. In addition to this, upstream is passed
-// for doing recursive queries against CNAMEs.
-// Returns error if it cannot verify any given domain name/zone id pair.
-func New(ctx context.Context, c route53iface.Route53API, keys map[string][]string, up *upstream.Upstream) (*Route53, error) {
+// zone id lists as its values, validates that each domain name/zone id pair
+// does exist, and returns a new *Route53. In addition to this, upstream is use
+// for doing recursive queries against CNAMEs. Returns error if it cannot
+// verify any given domain name/zone id pair.
+func New(ctx context.Context, c route53iface.Route53API, keys map[string][]string, refresh time.Duration) (*Route53, error) {
 	zones := make(map[string][]*zone, len(keys))
 	zoneNames := make([]string, 0, len(keys))
 	for dns, hostedZoneIDs := range keys {
@@ -71,7 +72,8 @@ func New(ctx context.Context, c route53iface.Route53API, keys map[string][]strin
 		client:    c,
 		zoneNames: zoneNames,
 		zones:     zones,
-		upstream:  up,
+		upstream:  upstream.New(),
+		refresh:   refresh,
 	}, nil
 }
 
@@ -87,7 +89,7 @@ func (h *Route53) Run(ctx context.Context) error {
 			case <-ctx.Done():
 				log.Infof("Breaking out of Route53 update loop: %v", ctx.Err())
 				return
-			case <-time.After(1 * time.Minute):
+			case <-time.After(h.refresh):
 				if err := h.updateZones(ctx); err != nil && ctx.Err() == nil /* Don't log error if ctx expired. */ {
 					log.Errorf("Failed to update zones: %v", err)
 				}
@@ -191,7 +193,7 @@ func maybeUnescape(s string) (string, error) {
 		case r >= rune('0') && r <= rune('9'):
 		case r == rune('*'):
 			if out != "" {
-				return "", errors.New("`*' ony supported as wildcard (leftmost label)")
+				return "", errors.New("`*' only supported as wildcard (leftmost label)")
 			}
 		case r == rune('-'):
 		case r == rune('.'):
@@ -248,6 +250,7 @@ func (h *Route53) updateZones(ctx context.Context) error {
 				newZ.Upstream = h.upstream
 				in := &route53.ListResourceRecordSetsInput{
 					HostedZoneId: aws.String(hostedZone.id),
+					MaxItems:     aws.String("1000"),
 				}
 				err = h.client.ListResourceRecordSetsPagesWithContext(ctx, in,
 					func(out *route53.ListResourceRecordSetsOutput, last bool) bool {
